@@ -178,7 +178,7 @@ impl Cell {
     {
         // get the dna
         let dna_file = conductor_handle
-            .get_dna(id.dna_hash())
+            .get_dna_file(id.dna_hash())
             .ok_or_else(|| DnaError::DnaMissing(id.dna_hash().to_owned()))?;
 
         let conductor_api = CellConductorApi::new(conductor_handle.clone(), id.clone());
@@ -787,11 +787,26 @@ impl Cell {
         call: ZomeCall,
         workspace_lock: Option<SourceChainWorkspace>,
     ) -> CellResult<ZomeCallResult> {
-        // Check if init has run if not run it
-        self.check_or_run_zome_init().await?;
+        // Only check if init has run if this call is not coming from
+        // an already running init call.
+        if workspace_lock
+            .as_ref()
+            .map_or(true, |w| !w.called_from_init())
+        {
+            // Check if init has run if not run it
+            self.check_or_run_zome_init().await?;
+        }
 
         let keystore = self.conductor_api.keystore().clone();
 
+        let conductor_handle = self.conductor_handle.clone();
+        let signal_tx = self.signal_broadcaster().await;
+        let ribosome = self.get_ribosome().await?;
+        let invocation =
+            ZomeCallInvocation::try_from_interface_call(self.conductor_api.clone(), call).await?;
+
+        let dna_def = ribosome.dna_def().as_content().clone();
+
         // If there is no existing zome call then this is the root zome call
         let is_root_zome_call = workspace_lock.is_none();
         let workspace_lock = match workspace_lock {
@@ -803,17 +818,12 @@ impl Cell {
                     self.cache().clone(),
                     keystore.clone(),
                     self.id.agent_pubkey().clone(),
+                    Arc::new(dna_def),
                 )
                 .await?
             }
         };
 
-        let conductor_handle = self.conductor_handle.clone();
-        let signal_tx = self.signal_broadcaster().await;
-        let ribosome = self.get_ribosome().await?;
-        let invocation =
-            ZomeCallInvocation::try_from_interface_call(self.conductor_api.clone(), call).await?;
-
         let args = CallZomeWorkflowArgs {
             cell_id: self.id.clone(),
             ribosome,
@@ -849,13 +859,22 @@ impl Cell {
         let keystore = self.conductor_api.keystore().clone();
         let id = self.id.clone();
         let conductor_handle = self.conductor_handle.clone();
+
+        // get the dna
+        let dna_file = conductor_handle
+            .get_dna_file(id.dna_hash())
+            .ok_or_else(|| DnaError::DnaMissing(id.dna_hash().to_owned()))?;
+
+        let dna_def = dna_file.dna_def().clone();
+
         // Create the workspace
-        let workspace = SourceChainWorkspace::new(
+        let workspace = SourceChainWorkspace::init_as_root(
             self.authored_env().clone(),
             self.dht_env().clone(),
             self.cache().clone(),
             keystore.clone(),
             id.agent_pubkey().clone(),
+            Arc::new(dna_def),
         )
         .await?;
 
@@ -865,20 +884,17 @@ impl Cell {
         }
         trace!("running init");
 
-        // get the dna
-        let dna_file = conductor_handle
-            .get_dna(id.dna_hash())
-            .ok_or_else(|| DnaError::DnaMissing(id.dna_hash().to_owned()))?;
-        let dna_def = dna_file.dna_def().clone();
-
         // Get the ribosome
         let ribosome = RealRibosome::new(dna_file);
 
+        let signal_tx = self.signal_broadcaster().await;
+
         // Run the workflow
         let args = InitializeZomesWorkflowArgs {
-            dna_def,
             ribosome,
             conductor_handle,
+            signal_tx,
+            cell_id: self.id.clone(),
         };
         let init_result =
             initialize_zomes_workflow(workspace, self.holochain_p2p_cell.clone(), keystore, args)
