@@ -226,97 +226,6 @@ async fn can_set_fake_state() {
     assert_eq!(state, conductor.get_state_from_handle().await.unwrap());
 }
 
-#[tokio::test(flavor = "multi_thread")]
-async fn proxy_tls_with_test_keystore() {
-    observability::test_run().ok();
-
-    let keystore1 = spawn_test_keystore().await.unwrap();
-    let keystore2 = spawn_test_keystore().await.unwrap();
-
-    if let Err(e) = proxy_tls_inner(keystore1.clone(), keystore2.clone()).await {
-        panic!("{:#?}", e);
-    }
-
-    let _ = keystore1.shutdown().await;
-    let _ = keystore2.shutdown().await;
-}
-
-async fn proxy_tls_inner(
-    keystore1: MetaLairClient,
-    keystore2: MetaLairClient,
-) -> anyhow::Result<()> {
-    use ghost_actor::GhostControlSender;
-    use kitsune_p2p::dependencies::*;
-    use kitsune_p2p_proxy::*;
-    use kitsune_p2p_types::transport::*;
-
-    let (cert_digest, cert, cert_priv_key) = keystore1.get_or_create_first_tls_cert().await?;
-
-    let tls_config1 = TlsConfig {
-        cert,
-        cert_priv_key,
-        cert_digest,
-    };
-
-    let (cert_digest, cert, cert_priv_key) = keystore2.get_or_create_first_tls_cert().await?;
-
-    let tls_config2 = TlsConfig {
-        cert,
-        cert_priv_key,
-        cert_digest,
-    };
-
-    let proxy_config =
-        ProxyConfig::local_proxy_server(tls_config1, AcceptProxyCallback::reject_all());
-    let (bind, evt) = kitsune_p2p_types::transport_mem::spawn_bind_transport_mem().await?;
-    let (bind1, mut evt1) = spawn_kitsune_proxy_listener(
-        proxy_config,
-        kitsune_p2p::dependencies::kitsune_p2p_types::config::KitsuneP2pTuningParams::default(),
-        bind,
-        evt,
-    )
-    .await?;
-    tokio::task::spawn(async move {
-        while let Some(evt) = evt1.next().await {
-            match evt {
-                TransportEvent::IncomingChannel(_, mut write, read) => {
-                    println!("YOOTH");
-                    let data = read.read_to_end().await;
-                    let data = String::from_utf8_lossy(&data);
-                    let data = format!("echo: {}", data);
-                    write.write_and_close(data.into_bytes()).await?;
-                }
-            }
-        }
-        TransportResult::Ok(())
-    });
-    let url1 = bind1.bound_url().await?;
-    println!("{:?}", url1);
-
-    let proxy_config =
-        ProxyConfig::local_proxy_server(tls_config2, AcceptProxyCallback::reject_all());
-    let (bind, evt) = kitsune_p2p_types::transport_mem::spawn_bind_transport_mem().await?;
-    let (bind2, _evt2) = spawn_kitsune_proxy_listener(
-        proxy_config,
-        kitsune_p2p::dependencies::kitsune_p2p_types::config::KitsuneP2pTuningParams::default(),
-        bind,
-        evt,
-    )
-    .await?;
-    println!("{:?}", bind2.bound_url().await?);
-
-    let (_url, mut write, read) = bind2.create_channel(url1).await?;
-    write.write_and_close(b"test".to_vec()).await?;
-    let data = read.read_to_end().await;
-    let data = String::from_utf8_lossy(&data);
-    assert_eq!("echo: test", data);
-
-    let _ = bind1.ghost_actor_shutdown_immediate().await;
-    let _ = bind2.ghost_actor_shutdown_immediate().await;
-
-    Ok(())
-}
-
 #[tokio::test(flavor = "multi_thread")]
 async fn test_list_running_apps_for_cell_id() {
     observability::test_run().ok();
