@@ -9,11 +9,14 @@ use holochain_conductor_api::conductor::EnvironmentRootPath;
 use holochain_p2p::dht_arc::{ArcInterval, DhtArcSet};
 use holochain_sqlite::{
     conn::{DbSyncLevel, DbSyncStrategy},
-    db::{DbKindAuthored, DbKindCache, DbKindDht, DbWrite},
+    db::{DbKindAuthored, DbKindCache, DbKindDht, DbWrite, ReadAccess},
     prelude::DatabaseResult,
 };
 use holochain_state::prelude::{from_blob, StateQueryResult};
-use holochain_types::dht_op::{DhtOp, DhtOpType};
+use holochain_types::{
+    db_cache::DhtDbQueryCache,
+    dht_op::{DhtOp, DhtOpType},
+};
 use holochain_zome_types::{Entry, EntryVisibility, SignedHeader, Timestamp};
 use kitsune_p2p::event::{TimeWindow, TimeWindowInclusive};
 use rusqlite::named_params;
@@ -65,6 +68,9 @@ pub struct Space {
     /// There is one per unique Dna.
     pub dht_env: DbWrite<DbKindDht>,
 
+    /// A cache for slow database queries.
+    pub dht_query_cache: DhtDbQueryCache,
+
     /// Countersigning workspace that is shared across this cell.
     pub countersigning_workspace: CountersigningWorkspace,
 
@@ -325,8 +331,16 @@ impl Spaces {
         dna_hash: &DnaHash,
         request_validation_receipt: bool,
         countersigning_session: bool,
-        ops: Vec<(holo_hash::DhtOpHash, holochain_types::dht_op::DhtOp)>,
+        ops: Vec<holochain_types::dht_op::DhtOp>,
     ) -> ConductorResult<()> {
+        use futures::StreamExt;
+        let ops = futures::stream::iter(ops.into_iter().map(|op| {
+            let hash = DhtOpHash::with_data_sync(&op);
+            (hash, op)
+        }))
+        .collect()
+        .await;
+
         // If this is a countersigning session then
         // send it to the countersigning workflow otherwise
         // send it to the incoming ops workflow.
@@ -391,6 +405,7 @@ impl Space {
         let countersigning_workspace = CountersigningWorkspace::new();
         let incoming_op_hashes = IncomingOpHashes::default();
         let incoming_ops_batch = IncomingOpsBatch::default();
+        let dht_query_cache = DhtDbQueryCache::new(dht_env.clone().into());
         let r = Self {
             dna_hash,
             cache,
@@ -399,6 +414,7 @@ impl Space {
             countersigning_workspace,
             incoming_op_hashes,
             incoming_ops_batch,
+            dht_query_cache,
         };
         Ok(r)
     }
