@@ -176,6 +176,7 @@ async fn test_pause_resume() {
 }
 
 #[tokio::test]
+#[ignore = "flaky due to dependence on timing"]
 async fn test_concurrency() {
     // - Trigger overrides already waiting listen.
     let (tx, mut rx) =
@@ -230,7 +231,7 @@ async fn publish_loop() {
     env.conn()
         .unwrap()
         .with_commit_test(|txn| {
-            mutations::insert_op(txn, op).unwrap();
+            mutations::insert_op(txn, &op).unwrap();
         })
         .unwrap();
     let mut dna_network = MockHolochainP2pDnaT::new();
@@ -302,7 +303,7 @@ async fn publish_loop() {
     env.conn()
         .unwrap()
         .with_commit_test(|txn| {
-            mutations::set_last_publish_time(txn, op_hash.clone(), five_mins_ago).unwrap();
+            mutations::set_last_publish_time(txn, &op_hash, five_mins_ago).unwrap();
         })
         .unwrap();
 
@@ -358,7 +359,7 @@ async fn publish_loop() {
     env.conn()
         .unwrap()
         .with_commit_test(|txn| {
-            mutations::set_last_publish_time(txn, op_hash.clone(), five_mins_ago).unwrap();
+            mutations::set_last_publish_time(txn, &op_hash, five_mins_ago).unwrap();
             mutations::set_receipts_complete(txn, &op_hash, false).unwrap();
         })
         .unwrap();
