@@ -1,4 +1,7 @@
 use super::error::WorkflowResult;
+use crate::conductor::api::CellConductorApi;
+use crate::conductor::api::CellConductorApiT;
+use crate::conductor::interface::SignalBroadcaster;
 use crate::conductor::ConductorHandle;
 use crate::core::ribosome::guest_callback::init::InitHostAccess;
 use crate::core::ribosome::guest_callback::init::InitInvocation;
@@ -19,9 +22,19 @@ pub struct InitializeZomesWorkflowArgs<Ribosome>
 where
     Ribosome: RibosomeT + Send + 'static,
 {
-    pub dna_def: DnaDef,
     pub ribosome: Ribosome,
     pub conductor_handle: ConductorHandle,
+    pub signal_tx: SignalBroadcaster,
+    pub cell_id: CellId,
+}
+
+impl<Ribosome> InitializeZomesWorkflowArgs<Ribosome>
+where
+    Ribosome: RibosomeT + Send + 'static,
+{
+    pub fn dna_def(&self) -> &DnaDef {
+        self.ribosome.dna_def().as_content()
+    }
 }
 
 #[instrument(skip(network, keystore, workspace, args))]
@@ -67,14 +80,24 @@ async fn initialize_zomes_workflow_inner<Ribosome>(
 where
     Ribosome: RibosomeT + Send + 'static,
 {
+    let dna_def = args.dna_def().clone();
     let InitializeZomesWorkflowArgs {
-        dna_def,
         ribosome,
         conductor_handle,
+        signal_tx,
+        cell_id,
     } = args;
+    let call_zome_handle =
+        CellConductorApi::new(conductor_handle.clone(), cell_id.clone()).into_call_zome_handle();
     // Call the init callback
     let result = {
-        let host_access = InitHostAccess::new(workspace.clone().into(), keystore, network.clone());
+        let host_access = InitHostAccess::new(
+            workspace.clone().into(),
+            keystore,
+            network.clone(),
+            signal_tx,
+            call_zome_handle,
+        );
         let invocation = InitInvocation { dna_def };
         ribosome.run_init(host_access, invocation)?
     };
@@ -96,7 +119,7 @@ where
     .await??;
 
     // TODO: Validate scratch items
-    super::inline_validation(workspace, network, conductor_handle, None, ribosome).await?;
+    super::inline_validation(workspace, network, conductor_handle, ribosome).await?;
 
     Ok(result)
 }
@@ -107,6 +130,7 @@ pub mod tests {
 
     use super::*;
     use crate::conductor::handle::MockConductorHandleT;
+    use crate::core::ribosome::guest_callback::validate::ValidateResult;
     use crate::core::ribosome::MockRibosomeT;
     use crate::fixt::DnaDefFixturator;
     use crate::fixt::MetaLairClientFixturator;
@@ -150,29 +174,38 @@ pub mod tests {
             .await
             .unwrap();
 
+        let dna_def = DnaDefFixturator::new(Unpredictable).next().unwrap();
+        let dna_def_hashed = DnaDefHashed::from_content_sync(dna_def.clone());
+
         let workspace = SourceChainWorkspace::new(
             env.clone(),
             test_dht.env(),
             test_cache.env(),
             keystore,
             author.clone(),
+            Arc::new(dna_def),
         )
         .await
         .unwrap();
         let mut ribosome = MockRibosomeT::new();
-        let dna_def = DnaDefFixturator::new(Unpredictable).next().unwrap();
-        let dna_def_hashed = DnaDefHashed::from_content_sync(dna_def.clone());
+
         // Setup the ribosome mock
         ribosome
             .expect_run_init()
             .returning(move |_workspace, _invocation| Ok(InitResult::Pass));
-        ribosome.expect_dna_def().return_const(dna_def_hashed);
+        ribosome
+            .expect_run_validate()
+            .returning(move |_, _| Ok(ValidateResult::Valid));
+        ribosome
+            .expect_dna_def()
+            .return_const(dna_def_hashed.clone());
 
         let conductor_handle = Arc::new(MockConductorHandleT::new());
         let args = InitializeZomesWorkflowArgs {
             ribosome,
-            dna_def,
             conductor_handle,
+            signal_tx: SignalBroadcaster::noop(),
+            cell_id: CellId::new(dna_def_hashed.to_hash(), author.clone()),
         };
         let keystore = fixt!(MetaLairClient);
         let network = fixt!(HolochainP2pDna);
