@@ -1,7 +1,5 @@
 //! The workflow and queue consumer for DhtOp integration
 
-use std::collections::HashMap;
-
 use super::*;
 use crate::core::queue_consumer::TriggerSender;
 use crate::core::queue_consumer::WorkComplete;
@@ -9,6 +7,7 @@ use error::WorkflowResult;
 use holochain_p2p::HolochainP2pDna;
 use holochain_p2p::HolochainP2pDnaT;
 use holochain_state::prelude::*;
+use holochain_types::db_cache::DhtDbQueryCache;
 use holochain_types::prelude::*;
 
 use tracing::*;
@@ -18,72 +17,34 @@ mod query_tests;
 #[cfg(feature = "test_utils")]
 mod tests;
 
-#[instrument(skip(vault, trigger_receipt, network))]
+#[instrument(skip(vault, trigger_receipt, network, dht_query_cache))]
 pub async fn integrate_dht_ops_workflow(
     vault: DbWrite<DbKindDht>,
+    dht_query_cache: &DhtDbQueryCache,
     trigger_receipt: TriggerSender,
     network: HolochainP2pDna,
 ) -> WorkflowResult<WorkComplete> {
     let start = std::time::Instant::now();
     let time = holochain_zome_types::Timestamp::now();
-    let changed = vault
+    // Get any activity from the cache that is ready to be integrated.
+    let activity_to_integrate = dht_query_cache.get_activity_to_integrate().await?;
+    let (changed, activity_integrated) = vault
         .async_commit(move |txn| {
-            let span = tracing::debug_span!("integrate_dht_ops_workflow");
-            let _g = span.enter();
-            let activity_integrated: Vec<(AgentPubKey, u32)> = txn
-                .prepare_cached(holochain_sqlite::sql::sql_cell::ACTIVITY_INTEGRATED_UPPER_BOUND)?
-                .query_map(
-                    named_params! {
-                        ":register_activity": DhtOpType::RegisterAgentActivity,
-                    },
-                    |row| {
-                        Ok((
-                            row.get::<_, Option<AgentPubKey>>(0)?,
-                            row.get::<_, Option<u32>>(1)?,
-                        ))
-                    },
-                )?
-                .filter_map(|r| match r {
-                    Ok((a, seq)) => Some(Ok((a?, seq?))),
-                    Err(e) => Some(Err(e)),
-                })
-                .collect::<rusqlite::Result<Vec<_>>>()?;
-            tracing::debug!(?activity_integrated);
-            let activity_missing: HashMap<AgentPubKey, i64> = txn
-                .prepare_cached(holochain_sqlite::sql::sql_cell::ACTIVITY_MISSING_DEP_UPPER_BOUND)?
-                .query_map(
-                    named_params! {
-                        ":register_activity": DhtOpType::RegisterAgentActivity,
-                    },
-                    |row| {
-                        Ok((
-                            row.get::<_, Option<AgentPubKey>>(0)?,
-                            row.get::<_, Option<i64>>(1)?,
-                        ))
-                    },
-                )?
-                .filter_map(|r| match r {
-                    Ok((a, seq)) => Some(Ok((a?, seq?))),
-                    Err(e) => Some(Err(e)),
-                })
-                .collect::<rusqlite::Result<HashMap<_, _>>>()?;
-            tracing::debug!(?activity_missing);
             let mut total = 0;
-            for (author, seq_integrated) in activity_integrated {
-                if let Some(seq_missing) = activity_missing.get(&author) {
-                    let changed = txn
-                        .prepare_cached(
-                            holochain_sqlite::sql::sql_cell::UPDATE_INTEGRATE_DEP_ACTIVITY,
-                        )?
-                        .execute(named_params! {
-                            ":when_integrated": time,
-                            ":register_activity": DhtOpType::RegisterAgentActivity,
-                            ":activity_integrated": seq_integrated,
-                            ":activity_missing": seq_missing,
-                            ":author": author,
-                        })?;
-                    tracing::debug!(?changed);
-                    total += changed;
+            if !activity_to_integrate.is_empty() {
+                let mut stmt = txn.prepare_cached(
+                    holochain_sqlite::sql::sql_cell::UPDATE_INTEGRATE_DEP_ACTIVITY,
+                )?;
+                for (author, seq_range) in &activity_to_integrate {
+                    let start = seq_range.start();
+                    let end = seq_range.end();
+                    total += stmt.execute(named_params! {
+                        ":when_integrated": time,
+                        ":register_activity": DhtOpType::RegisterAgentActivity,
+                        ":seq_start": start,
+                        ":seq_end": end,
+                        ":author": author,
+                    })?;
                 }
             }
             let changed = txn
@@ -125,9 +86,14 @@ pub async fn integrate_dht_ops_workflow(
 
                 })?;
             total += changed;
-            WorkflowResult::Ok(total)
+            WorkflowResult::Ok((total, activity_to_integrate))
         })
         .await?;
+    // Once the database transaction is committed, update the cache with the
+    // integrated activity.
+    dht_query_cache
+        .set_all_activity_to_integrated(activity_integrated)
+        .await?;
     let ops_ps = changed as f64 / start.elapsed().as_micros() as f64 * 1_000_000.0;
     tracing::debug!(?changed, %ops_ps);
     if changed > 0 {
