@@ -20,6 +20,7 @@ use holochain_state::host_fn_workspace::HostFnStores;
 use holochain_state::host_fn_workspace::HostFnWorkspace;
 use holochain_state::prelude::*;
 use holochain_state::scratch::SyncScratch;
+use holochain_types::db_cache::DhtDbQueryCache;
 use holochain_types::prelude::*;
 use holochain_zome_types::Entry;
 use holochain_zome_types::ValidationStatus;
@@ -104,7 +105,10 @@ async fn sys_validation_workflow_inner(
             async move {
                 let (op, op_hash) = so.into_inner();
                 let op_type = op.get_type();
-                let dependency = get_dependency(op_type, &op.header());
+                let header = op.header();
+
+                let dependency = get_dependency(op_type, &header);
+
                 let r = validate_op(
                     &op,
                     &(*workspace),
@@ -164,7 +168,7 @@ async fn sys_validation_workflow_inner(
                             total += 1;
                             put_validation_limbo(
                                 txn,
-                                op_hash,
+                                &op_hash,
                                 ValidationLimboStatus::SysValidated,
                             )?;
                         }
@@ -180,19 +184,19 @@ async fn sys_validation_workflow_inner(
                             // we were meant to get a StoreElement or StoreEntry or
                             // RegisterAgentActivity or RegisterAddLink.
                             let status = ValidationLimboStatus::AwaitingSysDeps(missing_dep);
-                            put_validation_limbo(txn, op_hash, status)?;
+                            put_validation_limbo(txn, &op_hash, status)?;
                         }
                         Outcome::MissingDhtDep => {
                             missing += 1;
                             // TODO: Not sure what missing dht dep is. Check if we need this.
-                            put_validation_limbo(txn, op_hash, ValidationLimboStatus::Pending)?;
+                            put_validation_limbo(txn, &op_hash, ValidationLimboStatus::Pending)?;
                         }
                         Outcome::Rejected => {
                             rejected += 1;
                             if let Dependency::Null = dependency {
-                                put_integrated(txn, op_hash, ValidationStatus::Rejected)?;
+                                put_integrated(txn, &op_hash, ValidationStatus::Rejected)?;
                             } else {
-                                put_integration_limbo(txn, op_hash, ValidationStatus::Rejected)?;
+                                put_integration_limbo(txn, &op_hash, ValidationStatus::Rejected)?;
                             }
                         }
                     }
@@ -200,6 +204,7 @@ async fn sys_validation_workflow_inner(
                 WorkflowResult::Ok((total, awaiting, missing, rejected))
             })
             .await?;
+
         total += t;
         if let (Some(start), Some(round_time)) = (start, &mut round_time) {
             let round_el = round_time.elapsed();
@@ -787,6 +792,7 @@ pub struct SysValidationWorkspace {
     scratch: Option<SyncScratch>,
     authored_env: DbRead<DbKindAuthored>,
     dht_env: DbRead<DbKindDht>,
+    dht_query_cache: Option<DhtDbQueryCache>,
     cache: DbWrite<DbKindCache>,
     pub(crate) dna_def: Arc<DnaDef>,
 }
@@ -795,21 +801,32 @@ impl SysValidationWorkspace {
     pub fn new(
         authored_env: DbRead<DbKindAuthored>,
         dht_env: DbRead<DbKindDht>,
+        dht_query_cache: DhtDbQueryCache,
         cache: DbWrite<DbKindCache>,
         dna_def: Arc<DnaDef>,
     ) -> Self {
         Self {
             authored_env,
             dht_env,
+            dht_query_cache: Some(dht_query_cache),
             cache,
             dna_def,
             scratch: None,
         }
     }
 
-    pub async fn is_chain_empty(&self, author: AgentPubKey) -> SourceChainResult<bool> {
+    pub async fn is_chain_empty(&self, author: &AgentPubKey) -> SourceChainResult<bool> {
+        // If we have a query cache then this is an authority node and
+        // we can quickly check if the chain is empty from the cache.
+        if let Some(c) = &self.dht_query_cache {
+            return Ok(c.is_chain_empty(author).await?);
+        }
+
+        // Otherwise we need to check this is an author node and
+        // we need to check the author db.
+        let author = author.clone();
         let chain_not_empty = self
-            .dht_env
+            .authored_env
             .async_reader(move |txn| {
                 let mut stmt = txn.prepare(
                     "
@@ -928,7 +945,7 @@ impl SysValidationWorkspace {
 
 fn put_validation_limbo(
     txn: &mut Transaction<'_>,
-    hash: DhtOpHash,
+    hash: &DhtOpHash,
     status: ValidationLimboStatus,
 ) -> WorkflowResult<()> {
     set_validation_stage(txn, hash, status)?;
@@ -937,23 +954,23 @@ fn put_validation_limbo(
 
 fn put_integration_limbo(
     txn: &mut Transaction<'_>,
-    hash: DhtOpHash,
+    hash: &DhtOpHash,
     status: ValidationStatus,
 ) -> WorkflowResult<()> {
-    set_validation_status(txn, hash.clone(), status)?;
+    set_validation_status(txn, hash, status)?;
     set_validation_stage(txn, hash, ValidationLimboStatus::AwaitingIntegration)?;
     Ok(())
 }
 
 pub fn put_integrated(
     txn: &mut Transaction<'_>,
-    hash: DhtOpHash,
+    hash: &DhtOpHash,
     status: ValidationStatus,
 ) -> WorkflowResult<()> {
-    set_validation_status(txn, hash.clone(), status)?;
+    set_validation_status(txn, hash, status)?;
     // This set the validation stage to pending which is correct when
     // it's integrated.
-    set_validation_stage(txn, hash.clone(), ValidationLimboStatus::Pending)?;
+    set_validation_stage(txn, hash, ValidationLimboStatus::Pending)?;
     set_when_integrated(txn, hash, Timestamp::now())?;
     Ok(())
 }
@@ -970,6 +987,7 @@ impl From<&HostFnWorkspace> for SysValidationWorkspace {
             scratch,
             authored_env: authored,
             dht_env: dht,
+            dht_query_cache: None,
             cache,
             dna_def: h.dna_def(),
         }
