@@ -13,11 +13,6 @@ use crate::core::ribosome::guest_callback::migrate_agent::MigrateAgentInvocation
 use crate::core::ribosome::guest_callback::post_commit::PostCommitHostAccess;
 use crate::core::ribosome::guest_callback::post_commit::PostCommitInvocation;
 use crate::core::ribosome::guest_callback::validate::ValidateHostAccess;
-use crate::core::ribosome::guest_callback::validate::ValidateInvocation;
-use crate::core::ribosome::guest_callback::validate_link::ValidateCreateLinkInvocation;
-use crate::core::ribosome::guest_callback::validate_link::ValidateDeleteLinkInvocation;
-use crate::core::ribosome::guest_callback::validate_link::ValidateLinkHostAccess;
-use crate::core::ribosome::guest_callback::validate_link::ValidateLinkInvocation;
 use crate::core::ribosome::guest_callback::validation_package::ValidationPackageHostAccess;
 use crate::core::ribosome::guest_callback::validation_package::ValidationPackageInvocation;
 use crate::core::ribosome::real_ribosome::RealRibosome;
@@ -245,7 +240,14 @@ fixturator!(
         let keystore = holochain_state::test_utils::test_keystore();
         tokio_helper::block_forever_on(async {
             fake_genesis(authored_env.env(), dht_env.env(), keystore.clone()).await.unwrap();
-            HostFnWorkspace::new(authored_env.env(), dht_env.env(), cache.env(), keystore, Some(fixt!(AgentPubKey, Predictable, get_fixt_index!()))).await.unwrap()
+            HostFnWorkspace::new(
+                authored_env.env(),
+                dht_env.env(),
+                cache.env(),
+                keystore,
+                Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
+                Arc::new(fixt!(DnaDef))
+            ).await.unwrap()
         })
     };
     curve Unpredictable {
@@ -255,7 +257,14 @@ fixturator!(
         let keystore = holochain_state::test_utils::test_keystore();
         tokio_helper::block_forever_on(async {
             fake_genesis(authored_env.env(), dht_env.env(), keystore.clone()).await.unwrap();
-            HostFnWorkspace::new(authored_env.env(), dht_env.env(), cache.env(), keystore, Some(fixt!(AgentPubKey, Predictable, get_fixt_index!()))).await.unwrap()
+            HostFnWorkspace::new(
+                authored_env.env(),
+                dht_env.env(),
+                cache.env(),
+                keystore,
+                Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
+                Arc::new(fixt!(DnaDef))
+            ).await.unwrap()
         })
     };
     curve Predictable {
@@ -266,7 +275,14 @@ fixturator!(
         let keystore = holochain_state::test_utils::test_keystore();
         tokio_helper::block_forever_on(async {
             crate::test_utils::fake_genesis_for_agent(authored_env.env(), dht_env.env(), agent.clone(), keystore.clone()).await.unwrap();
-            HostFnWorkspace::new(authored_env.env(), dht_env.env(), cache.env(), keystore, Some(agent)).await.unwrap()
+            HostFnWorkspace::new(
+                authored_env.env(),
+                dht_env.env(),
+                cache.env(),
+                keystore,
+                Some(agent),
+                Arc::new(fixt!(DnaDef))
+            ).await.unwrap()
         })
     };
 );
@@ -280,7 +296,14 @@ fixturator!(
         let keystore = holochain_state::test_utils::test_keystore();
         tokio_helper::block_forever_on(async {
             fake_genesis(authored_env.env(), dht_env.env(), keystore.clone()).await.unwrap();
-            HostFnWorkspaceRead::new(authored_env.env().into(), dht_env.env().into(), cache.env(), keystore, Some(fixt!(AgentPubKey, Predictable, get_fixt_index!()))).await.unwrap()
+            HostFnWorkspaceRead::new(
+                authored_env.env().into(),
+                dht_env.env().into(),
+                cache.env(),
+                keystore,
+                Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
+                Arc::new(fixt!(DnaDef))
+            ).await.unwrap()
         })
     };
     curve Unpredictable {
@@ -290,7 +313,14 @@ fixturator!(
         let keystore = holochain_state::test_utils::test_keystore();
         tokio_helper::block_forever_on(async {
             fake_genesis(authored_env.env(), dht_env.env(), keystore.clone()).await.unwrap();
-            HostFnWorkspaceRead::new(authored_env.env().into(), dht_env.env().into(), cache.env(), keystore, Some(fixt!(AgentPubKey, Predictable, get_fixt_index!()))).await.unwrap()
+            HostFnWorkspaceRead::new(
+                authored_env.env().into(),
+                dht_env.env().into(),
+                cache.env(),
+                keystore,
+                Some(fixt!(AgentPubKey, Predictable, get_fixt_index!())),
+                Arc::new(fixt!(DnaDef))
+            ).await.unwrap()
         })
     };
     curve Predictable {
@@ -301,7 +331,14 @@ fixturator!(
         let keystore = holochain_state::test_utils::test_keystore();
         tokio_helper::block_forever_on(async {
             crate::test_utils::fake_genesis_for_agent(authored_env.env(), dht_env.env(), agent.clone(), keystore.clone()).await.unwrap();
-            HostFnWorkspaceRead::new(authored_env.env().into(), dht_env.env().into(), cache.env(), keystore, Some(agent)).await.unwrap()
+            HostFnWorkspaceRead::new(
+                authored_env.env().into(),
+                dht_env.env().into(),
+                cache.env(),
+                keystore,
+                Some(agent),
+                Arc::new(fixt!(DnaDef))
+            ).await.unwrap()
         })
     };
 );
@@ -318,7 +355,7 @@ fixturator!(
 
 fixturator!(
     ZomeCallHostAccess;
-    constructor fn new(HostFnWorkspace, MetaLairClient, HolochainP2pDna, SignalBroadcaster, CellConductorReadHandle, CellId);
+    constructor fn new(HostFnWorkspace, MetaLairClient, HolochainP2pDna, SignalBroadcaster, CellConductorReadHandle);
 );
 
 fixturator!(
@@ -338,7 +375,7 @@ fixturator!(
 
 fixturator!(
     InitHostAccess;
-    constructor fn new(HostFnWorkspace, MetaLairClient, HolochainP2pDna);
+    constructor fn new(HostFnWorkspace, MetaLairClient, HolochainP2pDna, SignalBroadcaster, CellConductorReadHandle);
 );
 
 fixturator!(
@@ -366,61 +403,6 @@ fixturator!(
     constructor fn one(Zome);
 );
 
-fn make_validate_invocation(
-    zomes_to_invoke: ZomesToInvoke,
-    element: Element,
-) -> ValidateInvocation {
-    ValidateInvocation {
-        zomes_to_invoke,
-        element: Arc::new(element),
-        validation_package: None,
-        entry_def_id: None,
-    }
-}
-
-fixturator!(
-    ValidateInvocation;
-    vanilla fn make_validate_invocation(ZomesToInvoke, Element);
-);
-
-fixturator!(
-    ValidateCreateLinkInvocation;
-    constructor fn new(Zome, CreateLink, Entry, Entry);
-);
-
-fixturator!(
-    ValidateDeleteLinkInvocation;
-    constructor fn new(Zome, DeleteLink);
-);
-
-/// Macros don't get along with generics.
-type ValidateLinkInvocationCreate = ValidateLinkInvocation<ValidateCreateLinkInvocation>;
-
-fixturator!(
-    ValidateLinkInvocationCreate;
-    constructor fn new(ValidateCreateLinkInvocation);
-    curve Zome {
-        let mut c = ValidateCreateLinkInvocationFixturator::new(Empty)
-            .next()
-            .unwrap();
-        c.zome = get_fixt_curve!();
-        ValidateLinkInvocationCreate::new(c)
-    };
-);
-
-/// Macros don't get along with generics.
-type ValidateLinkInvocationDelete = ValidateLinkInvocation<ValidateDeleteLinkInvocation>;
-
-fixturator!(
-    ValidateLinkInvocationDelete;
-    constructor fn new(ValidateDeleteLinkInvocation);
-);
-
-fixturator!(
-    ValidateLinkHostAccess;
-    constructor fn new(HostFnWorkspace, HolochainP2pDna);
-);
-
 fixturator!(
     ValidateHostAccess;
     constructor fn new(HostFnWorkspace, HolochainP2pDna);
