@@ -205,9 +205,10 @@ where
 
     let (network, mut recv) = spawn_holochain_p2p(
         config,
-        holochain_p2p::kitsune_p2p::dependencies::kitsune_p2p_proxy::TlsConfig::new_ephemeral()
-            .await
-            .unwrap(),
+        holochain_p2p::kitsune_p2p::dependencies::kitsune_p2p_types::tls::TlsConfig::new_ephemeral(
+        )
+        .await
+        .unwrap(),
     )
     .await
     .unwrap();
@@ -482,7 +483,7 @@ fn get_published_ops<Db: ReadAccess<DbKindAuthored>>(
         txn.prepare(
             "
             SELECT
-            DhtOp.blob
+            DhtOp.type, Header.hash, Header.blob
             FROM DhtOp
             JOIN
             Header ON DhtOp.header_hash = Header.hash
@@ -497,7 +498,12 @@ fn get_published_ops<Db: ReadAccess<DbKindAuthored>>(
                 ":store_entry": DhtOpType::StoreEntry,
                 ":author": author,
             },
-            |row| from_blob(row.get("blob")?),
+            |row| {
+                let op_type: DhtOpType = row.get("type")?;
+                let hash: HeaderHash = row.get("hash")?;
+                let header: SignedHeader = from_blob(row.get("blob")?)?;
+                Ok(DhtOpLight::from_type(op_type, hash, &header.0)?)
+            },
         )
         .unwrap()
         .collect::<StateQueryResult<_>>()
