@@ -267,7 +267,7 @@ async fn wait_for_consistency(
             } => {
                 agents.remove(&from);
                 tracing::debug!(
-                    "{:?} has timed out before reaching consistency. \nMissing Agents: {:?}\nMissing Hashes: {:?}", 
+                    "{:?} has timed out before reaching consistency. \nMissing Agents: {:?}\nMissing Hashes: {:?}",
                     from,
                     missing_agents,
                     missing_hashes
@@ -635,10 +635,15 @@ async fn gather_published_data(
     let iter = iter.map(|stores| async move {
         let published_hashes = request_published_ops(&stores.authored_env).await?;
         let storage_arc = request_arc(&stores.p2p_env, (*stores.agent).clone()).await?;
-        Ok(storage_arc.map(|storage_arc| PublishedData {
-            agent: stores.agent,
-            storage_arc,
-            published_hashes,
+        Ok(storage_arc.map(|storage_arc| {
+            // The line below was added when migrating to rust edition 2021, per
+            // https://doc.rust-lang.org/edition-guide/rust-2021/disjoint-capture-in-closures.html#migration
+            let _ = &stores;
+            PublishedData {
+                agent: stores.agent,
+                storage_arc,
+                published_hashes,
+            }
         }))
     });
     futures::stream::iter(iter)
